pub struct Args {
pub month: Option<String>,
pub year: Option<i32>,
pub three: bool,
pub year_view: bool,
pub months: Option<u32>,
pub julian: bool,
pub persian: bool,
pub no_color: bool,
}Expand description
A Shahanshahi (Imperial Persian) calendar for the terminal.
Displays the current month by default. Accepts an optional month and year to show a specific month, or just a year to show all 12 months. Years are counted from the founding of the Persian Empire by Cyrus the Great.
Fields
month: Option<String>Month number (1-12) or name (farvardin, mordad, مرداد, …)
year: Option<i32>Shahanshahi year, e.g. 2584
three: boolDisplay the previous, current, and next month side by side
year_view: boolDisplay all 12 months of the year
months: Option<u32>Display the next NUM months starting from the current month
julian: boolDisplay day-of-year numbers instead of day-of-month
persian: boolUse Persian script (month names, weekday names, and digits)
no_color: boolDisable colored output (also respects NO_COLOR env variable)
Implementations